CRC8 class

Constructors

CRC8()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

crc8_tab List<int>
getter/setter pair

Static Methods

calcCrc8_1(List<int> data) int
计算CRC8校验值
calcCrc8_2(List<int> data, int offset, int len) int
计算CRC8校验值
calcCrc8_3(List<int> data, int offset, int len, int preval) int
计算CRC8校验值