HexUtil class

Constructors

HexUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bytesToHex(List<int> bytes) String
字节转hex字符
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

byteToBit(int b) String
字节转bit
hexToByte(String inHex) int
hex转字节
hexToByteArray(String inHex) List<int>
hex转字节数组
intToByte2(int sum) Uint8List
int转2字节
intToByte4(int sum) Uint8List
int转4字节