GlobalService class
Inheritance
Object
GetLifeCycle
DisposableInterface
GetxService
GlobalService
Mixed-in types
Properties
eventBus
↔ EventBus
getter/setter pair
hashCode
→ int
The hash code for this object.
no setter inherited
initialized
→ bool
Checks whether the controller has already been initialized.
no setter inherited
isClosed
→ bool
Checks whether the controller has already been closed.
no setter inherited
locale
↔ Locale
getter/setter pair
localeChangeCallback
↔ LocaleChangeCallback ?
getter/setter pair
onDelete
→ InternalFinalCallback<void >
Internal callback that starts the cycle of this controller.
final inherited
onStart
→ InternalFinalCallback<void >
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
sharedPreferences
↔ SharedPreferences
getter/setter pair
Methods
$configureLifeCycle ()
→ void
inherited
changeLocale (Locale value )
→ Future <void >
didChangeAccessibilityFeatures ()
→ void
Called when the system changes the set of currently active accessibility
features.
inherited
didChangeAppLifecycleState (AppLifecycleState state )
→ void
Called when the system puts the app in the background or returns
the app to the foreground.
inherited
didChangeLocales (List <Locale > ? locales )
→ void
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
didChangeMetrics ()
→ void
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
didChangePlatformBrightness ()
→ void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor ()
→ void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus (ViewFocusEvent event )
→ void
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
didHaveMemoryPressure ()
→ void
Called when the system is running low on memory.
inherited
didPopRoute ()
→ Future <bool >
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
didPushRoute (String route )
→ Future <bool >
Called when the host tells the application to push a new route onto the
navigator.
inherited
didPushRouteInformation (RouteInformation routeInformation )
→ Future <bool >
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit ()
→ Future <AppExitResponse >
Called when a request is received from the system to exit the application.
inherited
getDeviceInfo ()
→ Future <BaseDeviceInfo >
getPackageInfo ()
→ Future <PackageInfo >
handleCancelBackGesture ()
→ void
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
handleCommitBackGesture ()
→ void
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
handleStartBackGesture (PredictiveBackEvent backEvent )
→ bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap ()
→ void
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
handleUpdateBackGestureProgress (PredictiveBackEvent backEvent )
→ void
Called when a predictive back gesture moves.
inherited
init ({List <Locale > ? supportedLocales , LocaleChangeCallback ? localeChangeCallback })
→ Future <GlobalService >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose ()
→ void
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
onInit ()
→ void
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
onReady ()
→ void
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
toString ()
→ String
A string representation of this object.
inherited